pub struct CustomCurveFit { /* private fields */ }Implementations
Sourceimpl CustomCurveFit
impl CustomCurveFit
Sourcepub fn builder() -> Builder<FormulaStage>
pub fn builder() -> Builder<FormulaStage>
Returns a new builder.
Sourceimpl CustomCurveFit
impl CustomCurveFit
Sourcepub fn new(formula: StringConstant) -> Self
pub fn new(formula: StringConstant) -> Self
Constructs a new instance of the type.
Sourcepub fn formula(&self) -> &StringConstant
pub fn formula(&self) -> &StringConstant
A mathematical expression in terms of variable and parameter names, e.g. a * x + b * sin(x).
Variable names must match keys in the variables map; parameter names must match keys in the
parameters map.
Sourcepub fn variables(&self) -> &BTreeMap<LocalVariableName, CurveFitVariable>
pub fn variables(&self) -> &BTreeMap<LocalVariableName, CurveFitVariable>
Named input series referenced in the formula. Keys must match the variable names used in the formula expression.
Sourcepub fn parameters(&self) -> &BTreeMap<String, DoubleConstant>
pub fn parameters(&self) -> &BTreeMap<String, DoubleConstant>
Named fitting parameters and their initial guesses. Keys must match the parameter names used in
the formula expression; values are the starting points passed to the optimizer. The target the
curve is fit against is the y of the enclosing curve fit (the timeSeries series values, or the
scatter y series).