pub struct NumericEqualityRangesV2 { /* private fields */ }Expand description
Produces ranges where all numeric inputs are equal or are not all equal.
Implementations
Sourceimpl NumericEqualityRangesV2
impl NumericEqualityRangesV2
Sourcepub fn builder() -> Builder<EqualityOperatorStage>
pub fn builder() -> Builder<EqualityOperatorStage>
Returns a new builder.
Sourceimpl NumericEqualityRangesV2
impl NumericEqualityRangesV2
Sourcepub fn new(equality_operator: EqualityOperator) -> Self
pub fn new(equality_operator: EqualityOperator) -> Self
Constructs a new instance of the type.
Sourcepub fn inputs(&self) -> &[NumericSeries]
pub fn inputs(&self) -> &[NumericSeries]
The series compared against each other. At least two are required.
Sourcepub fn tolerance(&self) -> Option<&DoubleConstant>
pub fn tolerance(&self) -> Option<&DoubleConstant>
Maximum spread between the inputs still counted as equal. Defaults to zero, i.e. exact equality.
Sourcepub fn min_points(&self) -> Option<&IntegerConstant>
pub fn min_points(&self) -> Option<&IntegerConstant>
Minimum number of matching points. Defaults to 1.
Sourcepub fn min_duration(&self) -> Option<&Duration>
pub fn min_duration(&self) -> Option<&Duration>
Minimum matching duration. Defaults to one nanosecond.
Sourcepub fn range_start(&self) -> Option<&RangeStart>
pub fn range_start(&self) -> Option<&RangeStart>
Selects whether the output begins at the first match or after persistence is satisfied.
pub fn equality_operator(&self) -> &EqualityOperator