pub struct RangeDurationSeries { /* private fields */ }Expand description
Outputs a numeric series with one point per range: timestamp = range start, value = range duration.
Implementations
Sourceimpl RangeDurationSeries
impl RangeDurationSeries
Sourcepub fn builder() -> Builder<InputStage>
pub fn builder() -> Builder<InputStage>
Returns a new builder.
Sourceimpl RangeDurationSeries
impl RangeDurationSeries
Sourcepub fn new(
input: RangeSeries,
unbounded_range_behavior: UnboundedRangeBehavior,
) -> Self
pub fn new( input: RangeSeries, unbounded_range_behavior: UnboundedRangeBehavior, ) -> Self
Constructs a new instance of the type.
pub fn input(&self) -> &RangeSeries
Sourcepub fn unbounded_range_behavior(&self) -> &UnboundedRangeBehavior
pub fn unbounded_range_behavior(&self) -> &UnboundedRangeBehavior
How to handle ranges with a missing start or end.