pub struct RefpropSeriesV2 { /* private fields */ }Expand description
Computes a REFPROP output property from the supplied substance and output property.
Implementations
Sourceimpl RefpropSeriesV2
impl RefpropSeriesV2
Sourcepub fn builder() -> Builder<SubstanceStage>
pub fn builder() -> Builder<SubstanceStage>
Returns a new builder.
Sourceimpl RefpropSeriesV2
impl RefpropSeriesV2
Sourcepub fn new(
substance: RefpropSubstance,
output_property: RefpropProperty,
) -> Self
pub fn new( substance: RefpropSubstance, output_property: RefpropProperty, ) -> Self
Constructs a new instance of the type.
Sourcepub fn inputs(&self) -> &BTreeMap<RefpropProperty, NumericSeries>
pub fn inputs(&self) -> &BTreeMap<RefpropProperty, NumericSeries>
Map of REFPROP property to its numeric series.
Sourcepub fn substance(&self) -> &RefpropSubstance
pub fn substance(&self) -> &RefpropSubstance
The substance for REFPROP calculations.
Sourcepub fn output_property(&self) -> &RefpropProperty
pub fn output_property(&self) -> &RefpropProperty
The desired output property. This must not be one of the input properties.