pub struct ThresholdRangesV2 { /* private fields */ }Expand description
Produces ranges where a numeric input satisfies a threshold comparison.
Implementations
Sourceimpl ThresholdRangesV2
impl ThresholdRangesV2
Sourcepub fn builder() -> Builder<InputStage>
pub fn builder() -> Builder<InputStage>
Returns a new builder.
Sourceimpl ThresholdRangesV2
impl ThresholdRangesV2
Sourcepub fn new(input: NumericSeries, comparison: ThresholdRangesComparison) -> Self
pub fn new(input: NumericSeries, comparison: ThresholdRangesComparison) -> Self
Constructs a new instance of the type.
pub fn input(&self) -> &NumericSeries
Sourcepub fn min_points(&self) -> Option<&IntegerConstant>
pub fn min_points(&self) -> Option<&IntegerConstant>
Minimum number of matching points. Defaults to 1.
Sourcepub fn min_duration(&self) -> Option<&Duration>
pub fn min_duration(&self) -> Option<&Duration>
Minimum matching duration. Defaults to one nanosecond.
Sourcepub fn range_start(&self) -> Option<&RangeStart>
pub fn range_start(&self) -> Option<&RangeStart>
Selects whether the output begins at the first match or after persistence is satisfied.
pub fn comparison(&self) -> &ThresholdRangesComparison