pub struct BatchUpdateVideoFilesRequest { /* private fields */ }Expand description
Request to update metadata for multiple files within a single video. All files must belong to the provided video, and the batch may include at most 100 files.
Implementations
Sourceimpl BatchUpdateVideoFilesRequest
impl BatchUpdateVideoFilesRequest
Sourcepub fn builder() -> Builder<VideoRidStage>
pub fn builder() -> Builder<VideoRidStage>
Returns a new builder.
Sourceimpl BatchUpdateVideoFilesRequest
impl BatchUpdateVideoFilesRequest
Sourcepub fn new(video_rid: ResourceIdentifier) -> Self
pub fn new(video_rid: ResourceIdentifier) -> Self
Constructs a new instance of the type.
pub fn video_rid(&self) -> &ResourceIdentifier
pub fn updates(&self) -> &[VideoFileUpdate]