pub struct VideoChannelDatasetFileUpdate { /* private fields */ }Expand description
An update to apply to a single video dataset file backing a channel. Only the provided fields are changed; at least one must be set. When both start and scaleParameter are set, the file is rescaled first (around its current start) and then shifted to the new start.
Implementations
Sourceimpl VideoChannelDatasetFileUpdate
impl VideoChannelDatasetFileUpdate
Sourcepub fn builder() -> Builder<DatasetFileIdStage>
pub fn builder() -> Builder<DatasetFileIdStage>
Returns a new builder.
Sourceimpl VideoChannelDatasetFileUpdate
impl VideoChannelDatasetFileUpdate
pub fn dataset_file_id(&self) -> Uuid
Sourcepub fn start(&self) -> Option<&Timestamp>
pub fn start(&self) -> Option<&Timestamp>
New absolute start timestamp for the file. The file’s earliest segment is shifted to this timestamp and every other segment in the file is shifted by the same offset.
Sourcepub fn scale_parameter(&self) -> Option<&ScaleParameter>
pub fn scale_parameter(&self) -> Option<&ScaleParameter>
Rescales the file’s frame timestamps around its start (e.g. a corrected true frame rate, an absolute ending timestamp, or a direct scale factor). The file’s cached segment metadata (scale factor, frame rate) is recomputed.