pub struct TimeRangeInput { /* private fields */ }Expand description
A time range input that can be applied to panel(s)
Implementations
Sourceimpl TimeRangeInput
impl TimeRangeInput
Sourcepub fn builder() -> Builder<TimeRangeStage>
pub fn builder() -> Builder<TimeRangeStage>
Returns a new builder.
Sourceimpl TimeRangeInput
impl TimeRangeInput
Sourcepub fn new(time_range: Range, time_range_type: WorkbookTimeRangeType) -> Self
pub fn new(time_range: Range, time_range_type: WorkbookTimeRangeType) -> Self
Constructs a new instance of the type.
pub fn time_range(&self) -> &Range
Sourcepub fn time_range_type(&self) -> &WorkbookTimeRangeType
pub fn time_range_type(&self) -> &WorkbookTimeRangeType
The type of time range to use for the input.